@@ -33,9 +33,9 @@ class ComponentsSheet(Sheet):
 
         image_loader = SheetImageLoader(worksheet)
 
-        if len(worksheet._images) > 0:
-            image = worksheet._images[0]
-            filename: str = f"{uuid.uuid4()}.{image.format}"
+        for image_cell in image_loader._images:
+            image = image_loader.get(image_cell)
+            filename: str = f"{uuid.uuid4()}.{image.format.lower()}"
 
             self.components_data.components_image = \
                 NewImageData(
@@ -47,7 +47,7 @@ class ComponentsSheet(Sheet):
             self.components_image = \
                 NewImageFile(
                     filename=filename,
-                    file=image.ref,
+                    file=image.fp,
                 )
 
         self.process_data()
