@@ -6,7 +6,7 @@ from xlsx_lib.domain.engine.element_attribute import ElementAttribute
 
 
 class SectionElement(CamelModel):
-    name: str
+    name: Optional[str]
     value: Optional[str]
     observations: Optional[str]
     element_attributes: Optional[List[ElementAttribute]]
